@@ -31,12 +31,11 @@ extern char *strtok_r(char *s1, const char *s2, char **lasts);
 #define drand48 rand
 #endif
 
-int acc = 0;
-int maxfps = 60;
-
 Graphics::Graphics()
 {
 	fontIndex = 0;
+	
+	acc = 0;
 
 	screenShotNumber = 0;
 	
@@ -51,6 +50,8 @@ Graphics::Graphics()
 	
 	textWidth = textHeight = 0;
 	
+	allowMotionBlur = true;
+	
 	for (unsigned i = 0 ; i < MAX_RESOLUTIONS ; i++)
 	{
 		screenMode[i].x = screenMode[i].y = 0;
@@ -82,6 +83,8 @@ Graphics::Graphics()
 	redPulseDir = 1;
 	redPulse = 0;
 	
+	motionBlur = 100;
+	
 	gamma = 100;
 	
 	for (int i = 0 ; i < 13 ; i++)
@@ -363,7 +366,7 @@ void Graphics::clearScreen()
 	}
 }
 
-void Graphics::updateScreen()
+void Graphics::updateScreenMB()
 {
 	static const int maxacc = 256;
 	bool flush = false;
@@ -373,16 +376,23 @@ void Graphics::updateScreen()
 	acc++;
 
 	// Decide to flush accumulation buffer if another frame would make us miss the next vblank.
-	if(now - lastflush >= 1000 / maxfps || acc >= maxacc)
+	if (now - lastflush >= 1000 / motionBlur || acc >= maxacc)
+	{
 		flush = true;
+	}
 
 	// Accumulate this frame unless it's the first frame and we're flushing.
-	if(!flush || acc > 1)
+	if (!flush || acc > 1)
+	{
 		glAccum(acc > 1 ? GL_ACCUM : GL_LOAD, 1.0f / maxacc);
+	}
 
-	if(flush) {
-		if(acc > 1)
+	if (flush)
+	{
+		if (acc > 1)
+		{
 			glAccum(GL_RETURN, (float)maxacc / (float)acc);
+		}
 		acc = 0;
 		lastflush = now;
 		swapframes++;
@@ -403,6 +413,30 @@ void Graphics::updateScreen()
 	Math::wrap(&(animTimer += engine->getTimeDifference(TD_ANIMATION)), 0, RAND_MAX);
 }
 
+void Graphics::updateScreen()
+{
+	if (allowMotionBlur && motionBlur < 100)
+	{
+		updateScreenMB();
+		return;
+	}
+	
+	SDL_GL_SwapBuffers();
+	SDL_Delay(1);
+
+	if ((engine->keyState[SDLK_F10]) || ((engine->keyState[SDLK_RETURN]) && (engine->keyState[SDLK_LALT])))
+	{
+		SDL_WM_ToggleFullScreen(screen);
+		fullscreen = !fullscreen;
+
+		engine->keyState[SDLK_F10] = engine->keyState[SDLK_LALT] = engine->keyState[SDLK_RETURN] = 0;
+		
+		engine->resetTimeDifference();
+	}
+	
+	Math::wrap(&(animTimer += engine->getTimeDifference(TD_ANIMATION)), 0, RAND_MAX);
+}
+
 void Graphics::delay(int time, bool allowSkip)
 {
 	unsigned long then = SDL_GetTicks();
@@ -468,7 +502,8 @@ Texture *Graphics::loadTexture(const char *filename)
 	
 	if (strstr(filename, ".tga"))
 	{
-		image = IMG_LoadTyped_RW(pak->sdlrw, true, "TGA");
+		char type[] = "TGA";
+		image = IMG_LoadTyped_RW(pak->sdlrw, true, type);
 		
 		return createTextureFromTGA(image);
 	}
@@ -1268,7 +1303,7 @@ void Graphics::setFontColor(int red, int green, int blue, int red2, int green2,
 SDL_Surface *Graphics::createSurface(int width, int height)
 {
 	SDL_Surface *surface;
-	Uint32 rmask, gmask, bmask, amask;
+	Uint32 rmask, gmask, bmask;
 
 	/* SDL interprets each pixel as a 32-bit number, so our masks must depend
 	on the endianness (byte order) of the machine */
@@ -1276,12 +1311,10 @@ SDL_Surface *Graphics::createSurface(int width, int height)
 		rmask = 0xff000000;
 		gmask = 0x00ff0000;
 		bmask = 0x0000ff00;
-		amask = 0x000000ff;
 	#else
 		rmask = 0x000000ff;
 		gmask = 0x0000ff00;
 		bmask = 0x00ff0000;
-		amask = 0xff000000;
 	#endif
 
 	surface = SDL_CreateRGBSurface(SDL_SWSURFACE, width, height, 32, rmask, gmask, bmask, 0);
