@@ -40,16 +40,16 @@ const char *Objective::getStatus()
 	switch (status)
 	{
 		case OBJ_INCOMPLETE:
-			return "Incomplete";
+			return _("Incomplete");
 			
 		case OBJ_INPROGRESS:
-			return "In Progress";
+			return _("In Progress");
 			
 		case OBJ_COMPLETE:
-			return "Complete";
+			return _("Complete");
 			
 		case OBJ_FAILED:
-			return "Failed";
+			return _("Failed");
 	}
 	
 	return "";
