@@ -330,6 +330,13 @@ enum {
 #if DEV
 	#undef PAKFULLPATH
 	#define PAKFULLPATH PAKNAME
+	
+	/*
+	#ifdef LOCALEDIR
+		#undef LOCALEDIR
+	#endif
+	#define LOCALEDIR "locale/"
+	*/
 #endif
 
 struct PAK
