@@ -432,7 +432,6 @@ void doCheatOptions()
 
 void doAdditionalOptions()
 {
-	extern int maxfps;
 	uiManager->onlyShowGroup("additional");
 	
 	Grid *grid = uiManager->getGrid("AdditionalGrid");
@@ -443,30 +442,30 @@ void doAdditionalOptions()
 	ComboBox *shadows = (ComboBox*)uiManager->getWidget("Shadows", "additional");
 	ComboBox *decals = (ComboBox*)uiManager->getWidget("Decals", "additional");
 	CheckBox *swap = (CheckBox*)uiManager->getWidget("SwapAxis", "additional");
-	Slider *fpslimit = (Slider*)uiManager->getWidget("FPSlimit", "additional");
+	Slider *blur = (Slider*)uiManager->getWidget("Blur", "additional");
 	
 	Button *done = (Button*)uiManager->getWidget("Done", "additional");
 	
-	blood->addItem("Off");
-	blood->addItem("No Stains");
-	blood->addItem("On");
+	blood->addItem(_("Off"));
+	blood->addItem(_("No Stains"));
+	blood->addItem(_("On"));
 
 	if (graphics->hasStencils)
 	{	
-		shadows->addItem("Off");
-		shadows->addItem("Bob Only");
-		shadows->addItem("Blobs and Enemies");
-		shadows->addItem("On");
+		shadows->addItem(_("Off"));
+		shadows->addItem(_("Bob Only"));
+		shadows->addItem(_("Blobs and Enemies"));
+		shadows->addItem(_("On"));
 	}
 	else
 	{
-		shadows->addItem("Not Available (no stencil support)");
+		shadows->addItem(_("Not Available (no stencil support)"));
 	}
 	
-	decals->addItem("Off");
-	decals->addItem("Low");
-	decals->addItem("Medium");
-	decals->addItem("On");
+	decals->addItem(_("Off"));
+	decals->addItem(_("Low"));
+	decals->addItem(_("Medium"));
+	decals->addItem(_("On"));
 	
 	blood->setSelectedItem(game->bloodPolicy);
 	decals->setSelectedItem(game->decalPolicy);
@@ -474,7 +473,7 @@ void doAdditionalOptions()
 	
 	swap->checked = engine->swapSecondStickAxis;
 	
-	fpslimit->value = maxfps;
+	blur->value = 100 - graphics->motionBlur;
 
 	engine->resetTimeDifference();
 	
@@ -512,7 +511,7 @@ void doAdditionalOptions()
 	game->decalPolicy = decals->selectedItem;
 	game->shadowPolicy = shadows->selectedItem;
 	engine->swapSecondStickAxis = swap->checked;
-	maxfps = fpslimit->value;
+	graphics->motionBlur = 100 - blur->value;
 	
 	blood->clear();
 	decals->clear();
@@ -697,6 +696,11 @@ void doConfigOptions()
 			audio->setAmbientVolume((int)ambientVolume->value);
 		}
 		
+		if (environmentVolume->hasChanged())
+		{
+			audio->setEnvironmentVolume((int)environmentVolume->value);
+		}
+		
 		if (brightness->hasChanged())
 		{
 			graphics->gamma = 50 + brightness->value;
