@@ -53,10 +53,9 @@ void drawSelectedListItem(float x, float y, float w, float h, bool isSelectedWid
 
 void drawListView(ListView *listView)
 {
-	int xLoc, yLoc, index;
+	int yLoc, index;
 	
 	listView->visibleItems = 0;
-	xLoc = listView->x + listView->width;
 	yLoc = listView->y + 2;
 	index = 0;
 	GLColor blue, green;
@@ -66,7 +65,7 @@ void drawListView(ListView *listView)
 	
 	if (listView->getNumberOfPages() > 1)
 	{
-		graphics->drawString(listView->x + listView->width, listView->y - 20, TXT_RIGHT, GLColor::white, true, "Page %d / %d", listView->getCurrentPage(), listView->getNumberOfPages());
+		graphics->drawString(listView->x + listView->width, listView->y - 20, TXT_RIGHT, GLColor::white, true, _("Page %d / %d"), listView->getCurrentPage(), listView->getNumberOfPages());
 	}
 	
 	if (!listView->transparent)
@@ -198,7 +197,7 @@ void drawInputWidget(InputWidget *inputWidget)
 	
 	if (inputWidget->redraw)
 	{
-		renderString = "N/A";
+		renderString = _("N/A");
 		keyString = "";
 		joyString = "";
 		mouseString = "";
@@ -213,7 +212,7 @@ void drawInputWidget(InputWidget *inputWidget)
 			if (keyName != "unknown key")
 			{
 				keyName.captialise();
-				keyString = keyName.getText();
+				keyString = _(keyName.getText());
 				useOr = true;
 			}
 		}
@@ -315,9 +314,8 @@ BaseWidget *createButtonWidget(Properties *props)
 	button->setProperties(props);
 	createWidgetColors(button, props);
 
-	int color, disabledRed, disabledGreen, disabledBlue;
+	int disabledRed, disabledGreen, disabledBlue;
 	
-	color = graphics->getColor(button->backgroundColorRed, button->backgroundColorGreen, button->backgroundColorBlue);
 	disabledRed = button->backgroundColorRed / 2;
 	disabledGreen = button->backgroundColorGreen / 2;
 	disabledBlue = button->backgroundColorBlue / 2;
