@@ -61,7 +61,7 @@ void showLicense()
 		{
 			y += dy;
 		
-			graphics->drawString(graphics->screenMidX, y, TXT_CENTERED, GLColor::white, true, line);
+			graphics->drawString(graphics->screenMidX, y, TXT_CENTERED, GLColor::white, true, "%s", line);
 		}
 		
 		token = strtok(NULL, "\n");
@@ -207,6 +207,7 @@ void loadConfig()
 	game->bloodPolicy = props->getInt("bloodPolicy", BLOOD_POLICY_ON);
 	game->shadowPolicy = props->getInt("shadowPolicy", SHADOW_POLICY_ON);
 	game->decalPolicy = props->getInt("decalPolicy", DECAL_POLICY_ON);
+	graphics->motionBlur = props->getInt("motionBlur", 100);
 	
 	engine->swapSecondStickAxis = props->getInt("swapSecondStickAxis", 0);
 	
@@ -266,6 +267,7 @@ void saveConfig()
 	props.setProperty("bloodPolicy", game->bloodPolicy);
 	props.setProperty("shadowPolicy", game->shadowPolicy);
 	props.setProperty("decalPolicy", game->decalPolicy);
+	props.setProperty("motionBlur", graphics->motionBlur);
 	
 	props.setProperty("swapSecondStickAxis", engine->swapSecondStickAxis);
 	
@@ -357,8 +359,8 @@ void initCommonResources()
 
 	graphics->loadFont(FONT_NORMAL, "data/fonts/vera.ttf", 12);
 	graphics->loadFont(FONT_LARGE, "data/fonts/vera.ttf", 32);
-	graphics->loadFont(FONT_DIGITAL, "data/fonts/909.ttf", 32);
-	graphics->loadFont(FONT_LARGE_DIGITAL, "data/fonts/909.ttf", 5);
+	graphics->loadFont(FONT_DIGITAL, "data/fonts/vera.ttf", 32);
+	graphics->loadFont(FONT_LARGE_DIGITAL, "data/fonts/vera.ttf", 5);
 	graphics->loadFont(FONT_NUMBER, "data/fonts/vera.ttf", 5);
 	graphics->loadTimerDigits();
 
