@@ -18,10 +18,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <sys/stat.h>
-#include <pwd.h>
-#include <unistd.h>
-#include <errno.h>
+#ifdef __unix__
+	#include <sys/stat.h>
+	#include <pwd.h>
+	#include <unistd.h>
+	#include <errno.h>
+#endif
 
 #include "headers.h"
 
