@@ -165,7 +165,7 @@ void loadWeapons()
 		
 		weaponDef->type = weaponId;
 		
-		weaponDef->name = props->getString("name", "NULL");
+		weaponDef->name = _(props->getString("name", "NULL"));
 		
 		weaponDef->modelName[0] = props->getString("model1", "NULL");
 		weaponDef->modelName[1] = props->getString("model2", "NULL");
@@ -220,7 +220,7 @@ void loadItems()
 		
 		itemDef->type = itemId;
 		
-		itemDef->name = props->getString("name", "NULL");
+		itemDef->name = _(props->getString("name", "NULL"));
 	
 		itemDef->modelName[0] = props->getString("model1", "NULL");
 		itemDef->modelName[1] = props->getString("model2", "NULL");
@@ -493,7 +493,7 @@ void loadAllDefResources(EntityDef *def)
 
 void loadAllDefResources()
 {
-	graphics->showLoadingProgress("Loading Resources...");
+	graphics->showLoadingProgress(_("Loading Resources..."));
 	
 	debug(("loadAllDefResources()\n"));
 	
@@ -534,7 +534,7 @@ void loadAllBattleResources()
 
 void loadMapAudio()
 {
-	graphics->showLoadingProgress("Loading Music...");
+	graphics->showLoadingProgress(_("Loading Music..."));
 	
 	audio->freeSound(SND_WEATHER);
 	
