@@ -103,6 +103,7 @@ int doTitle()
 	audio->playMusic();
 	
 	graphics->delay(1000, false);
+	graphics->allowMotionBlur = false;
 	
 	engine->resetTimeDifference();
 	
@@ -218,15 +219,9 @@ int doTitle()
 	audio->stopMusic();
 	
 	graphics->clearScreen();
+	graphics->updateScreen();
 	
-	if (rtn != SECTION_TITLE)
-	{
-		graphics->delay(1000, false);
-	}
-	else
-	{
-		graphics->delay(1, false);
-	}
+	graphics->allowMotionBlur = true;
 	
 	return rtn;
 }
@@ -238,6 +233,7 @@ void doIntro()
 
 	mouse->setBusy(false);
 	
+	graphics->allowMotionBlur = false;
 	graphics->clearScreen();
 	
 	List introData;
@@ -303,6 +299,7 @@ void doIntro()
 	graphics->clearScreen();
 	graphics->updateScreen();
 	graphics->delay(1000, false);
+	graphics->allowMotionBlur = true;
 }
 
 void doCredits()
@@ -348,7 +345,7 @@ void doCredits()
 			
 		y += pos;
 			
-		credit[lastCredit] = graphics->getGLString(cred);
+		credit[lastCredit] = graphics->getGLString("%s", cred);
 		cy[lastCredit] = y;
 	
 		token = strtok(NULL, "\n");
