@@ -114,7 +114,7 @@ int tesselate(BSPBiQuadraticPatch *quadPatch)
 
 	if (quadPatch->verts == NULL)
 	{
-		graphics->showErrorAndExit("BSP - Failed to allocate %u bytes for tesselation", (bsp->tesselation + 1) * (bsp->tesselation + 1) * sizeof(BSPVertex));
+		graphics->showErrorAndExit("BSP - Failed to allocate %zu bytes for tesselation", (bsp->tesselation + 1) * (bsp->tesselation + 1) * sizeof(BSPVertex));
 	}
 
 	for (v=0;v<=bsp->tesselation;v++)
@@ -206,7 +206,7 @@ int tesselate(BSPBiQuadraticPatch *quadPatch)
 
 	if (quadPatch->indices == NULL)
 	{
-		graphics->showErrorAndExit("BSP - Failed to allocate %u bytes for indices", bsp->tesselation * (bsp->tesselation + 1) * 2 * sizeof(unsigned int));
+		graphics->showErrorAndExit("BSP - Failed to allocate %zu bytes for indices", bsp->tesselation * (bsp->tesselation + 1) * 2 * sizeof(unsigned int));
 	}
 
 	for (row=0;row<bsp->tesselation;row++)
@@ -224,12 +224,12 @@ int tesselate(BSPBiQuadraticPatch *quadPatch)
 
 	if (quadPatch->trianglesPerRow == NULL)
 	{
-		graphics->showErrorAndExit("BSP - Failed to allocate %d bytes for trianglesPerRow", bsp->tesselation * sizeof(int));
+		graphics->showErrorAndExit("BSP - Failed to allocate %zu bytes for trianglesPerRow", bsp->tesselation * sizeof(int));
 	}
 
 	if (quadPatch->rowIndexPointers == NULL)
 	{
-		graphics->showErrorAndExit("BSP - Failed to allocate %u bytes for rowIndexPointers", bsp->tesselation * sizeof(unsigned int));
+		graphics->showErrorAndExit("BSP - Failed to allocate %zu bytes for rowIndexPointers", bsp->tesselation * sizeof(unsigned int));
 	}
 
 	for (row=0;row<bsp->tesselation;row++)
@@ -381,14 +381,14 @@ int loadTextures(unsigned char *buffer, BSPLump *lumps)
 
 	if (bsp->textures == NULL)
 	{
-		graphics->showErrorAndExit("BSP - Failed to allocate %u bytes for textures", bsp->numOfTextures * sizeof(BSPTexture));
+		graphics->showErrorAndExit("BSP - Failed to allocate %zu bytes for textures", bsp->numOfTextures * sizeof(BSPTexture));
 	}
 
 	bsp->textureSpec = (TextureSpec **)malloc(bsp->numOfTextures * sizeof(TextureSpec *));
 
 	if (bsp->textureSpec == NULL)
 	{
-		graphics->showErrorAndExit("BSP - Failed to allocate %u bytes for texture validation", bsp->numOfTextures * sizeof(TextureSpec));
+		graphics->showErrorAndExit("BSP - Failed to allocate %zu bytes for texture validation", bsp->numOfTextures * sizeof(TextureSpec));
 	}
 
 	buffer += lumps[kTextures].offset;
@@ -423,6 +423,13 @@ int loadLightmaps(unsigned char *buffer, BSPLump *lumps)
 
 	debug(("BSP: %d lightmaps\n", bsp->numOfLightmaps));
 
+	bsp->lightmapTextures = (unsigned int *)malloc(bsp->numOfLightmaps * sizeof(unsigned int));
+
+	if (bsp->lightmapTextures == NULL)
+	{
+		return 1;
+	}
+
 	lightmaps = (BSPLightmap *)malloc(bsp->numOfLightmaps * sizeof(BSPLightmap));
 
 	if (lightmaps == NULL)
@@ -434,13 +441,6 @@ int loadLightmaps(unsigned char *buffer, BSPLump *lumps)
 	
 	memcpy(lightmaps, buffer, sizeof(BSPLightmap) * bsp->numOfLightmaps);
 
-	bsp->lightmapTextures = (unsigned int *)malloc(bsp->numOfLightmaps * sizeof(unsigned int));
-
-	if (bsp->lightmapTextures == NULL)
-	{
-		return 1;
-	}
-
 	glGenTextures(bsp->numOfLightmaps, bsp->lightmapTextures);
 
 	white[0] = 1.0f;
@@ -845,7 +845,7 @@ int loadPatches(unsigned char *buffer, BSPLump *lumps)
 
 		if (bsp->patches == NULL)
 		{
-			printf("Failed to allocate %u bytes for patches\n", bsp->numOfPatches * sizeof(BSPPatch));
+			printf("Failed to allocate %zu bytes for patches\n", bsp->numOfPatches * sizeof(BSPPatch));
 	
 			exit(1);
 		}
@@ -1303,11 +1303,10 @@ int isClusterVisible(int cluster)
 void renderBSP()
 {
 	Vector position;
-	int cameraLeaf, i, j, facesToDraw, faceIndex;
+	int cameraLeaf, i, j, faceIndex;
 
 	memset(bsp->facesDrawn.bits, 0, sizeof(unsigned int) * bsp->facesDrawn.size);
 	
-	facesToDraw   = 0;
 	cameraLeaf    = calculateEntityLeaf(camera->getRenderingTarget());
 	camera->cluster = bsp->leafs[cameraLeaf].cluster;
 
